# Weights and Biases Addons

## What is it?

Additional toolbox for Weights & Biases

## Main Features

- **wandb clean_local** TBA.

## Where to get it

wandb_addons can be installed from PyPI using `pip`:

```bash
pip install wandb_addons
```

## Interface

TBA.
